package com.bonus.canteen.core.menu.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.bonus.canteen.core.menu.domain.MenuMaterial;
import com.bonus.canteen.core.menu.dto.IntegerIds;
import com.bonus.canteen.core.menu.service.IMenuMaterialService;
import com.bonus.common.log.enums.OperaType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 商家食材原料信息Controller
 *
 * @author xsheng
 * @date 2025-04-03
 */
@Api(tags = "商家食材原料信息接口")
@RestController
@RequestMapping("/menu_material")
public class MenuMaterialController extends BaseController {
    @Autowired
    private IMenuMaterialService menuMaterialService;

    /**
     * 查询商家食材原料信息列表
     */
    @ApiOperation(value = "查询商家食材原料信息列表")
    //@RequiresPermissions("menu:material:list")
    @GetMapping("/list")
    public TableDataInfo list(MenuMaterial menuMaterial) {
        startPage();
        List<MenuMaterial> list = menuMaterialService.selectMenuMaterialList(menuMaterial);
        return getDataTable(list);
    }

    /**
     * 导出商家食材原料信息列表
     */
    @ApiOperation(value = "导出商家食材原料信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:material:export")
    @SysLog(title = "商家食材原料信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出商家食材原料信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MenuMaterial menuMaterial) {
        List<MenuMaterial> list = menuMaterialService.selectMenuMaterialList(menuMaterial);
        ExcelUtil<MenuMaterial> util = new ExcelUtil<MenuMaterial>(MenuMaterial.class);
        util.exportExcel(response, list, "商家食材原料信息数据");
    }

    /**
     * 获取商家食材原料信息详细信息
     */
    @ApiOperation(value = "获取商家食材原料信息详细信息")
    //@RequiresPermissions("menu:material:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(menuMaterialService.selectMenuMaterialById(id));
    }

    /**
     * 新增商家食材原料信息
     */
    @ApiOperation(value = "新增商家食材原料信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:material:add")
    @SysLog(title = "商家食材原料信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增商家食材原料信息")
    @PostMapping("/addMessage")
    public AjaxResult add(@RequestBody MenuMaterial menuMaterial) {
        try {
            return toAjax(menuMaterialService.insertMenuMaterial(menuMaterial));
        } catch (Exception e) {
            return error(e.getMessage());
        }

    }


    /**
     * 修改商家食材原料信息
     */
    @ApiOperation(value = "修改商家食材原料信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:material:edit")
    @SysLog(title = "商家食材原料信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改商家食材原料信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody MenuMaterial menuMaterial) {
        try {
            return toAjax(menuMaterialService.updateMenuMaterial(menuMaterial));
        } catch (Exception e) {
            return error( e.getMessage());
        }
    }

    /**
     * 删除商家食材原料信息
     */
    @ApiOperation(value = "删除商家食材原料信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:material:remove")
    @SysLog(title = "商家食材原料信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除商家食材原料信息")
	@PostMapping("/del")
    public AjaxResult remove(@RequestBody IntegerIds ids) {
        return toAjax(menuMaterialService.deleteMenuMaterialByIds(ids.getIds()));
    }
}
